## Torrent Crawler and Search
> Search for torrents using command line
```bash
pip3 install search-torrent
search-torrent
```

<p align="center"><img src="img/search-torrent-colorized.gif?raw=true"/></p>

---
### Contributing
```bash
git clone https://github.com/rajat19/torrent-search.git
cd torrent-search
pip install -r requirements.txt
python setup.py install
python search.py
```

---
### What's new
Added support to download subtitles for the movie as well

---
### What's next
- Allow user to stop movie search in between
- Store search history in cache or something for faster processing
